@@ -1,7 +1,7 @@
 package Config::IOD::Base;
 
-our $DATE = '2015-05-05'; # DATE
-our $VERSION = '0.16'; # VERSION
+our $DATE = '2015-06-07'; # DATE
+our $VERSION = '0.17'; # VERSION
 
 use 5.010001;
 use strict;
@@ -362,9 +362,9 @@ sub _push_include_stack {
     # included file's path is based on the main (topmost) file
     if (@{ $self->{_include_stack} }) {
         require File::Spec;
-        my (undef, $dir, $file) =
+        my ($vol, $dir, $file) =
             File::Spec->splitpath($self->{_include_stack}[-1]);
-        $path = File::Spec->rel2abs($path, $dir);
+        $path = File::Spec->rel2abs($path, File::Spec->catpath($vol, $dir));
     }
 
     my $abs_path = Cwd::abs_path($path) or return [400, "Invalid path name"];
@@ -429,7 +429,7 @@ Config::IOD::Base - Base class for Config::IOD and Config::IOD::Reader
 
 =head1 VERSION
 
-This document describes version 0.16 of Config::IOD::Base (from Perl distribution Config-IOD-Reader), released on 2015-05-05.
+This document describes version 0.17 of Config::IOD::Base (from Perl distribution Config-IOD-Reader), released on 2015-06-07.
 
 =head1 ATTRIBUTES
 
